@@ -2,15 +2,14 @@
 
 // This example is used as an example in the README for the action handler.
 
-// const { Command } = require('commander'); // (normal include)
-const { Command } = require('../'); // include commander in git clone of commander repo
+const { Command } = require('commander');
 const program = new Command();
 
 program
   .command('serve')
   .argument('<script>')
   .option('-p, --port <number>', 'port number', 80)
-  .action(function() {
+  .action(function () {
     console.error('Run script %s on port %s', this.args[0], this.opts().port);
   });
 
