@@ -4,11 +4,10 @@
 //    Custom argument processing
 //    You may specify a function to do custom processing of argument values.
 
-// const commander = require('commander'); // (normal include)
-const commander = require('../'); // include commander in git clone of commander repo
+const commander = require('commander');
 const program = new commander.Command();
 
-function myParseInt(value, dummyPrevious) {
+function myParseInt(value) {
   // parseInt takes a string and a radix
   const parsedValue = parseInt(value, 10);
   if (isNaN(parsedValue)) {
