@@ -1,6 +1,4 @@
-// const commander = require('commander'); // (normal include)
-const commander = require('../'); // include commander in git clone of commander repo
-
+const commander = require('commander');
 const program = new commander.Command();
 
 // This example shows a simple use of configureHelp.
@@ -10,11 +8,17 @@ const program = new commander.Command();
 
 program.configureHelp({
   sortSubcommands: true,
-  subcommandTerm: (cmd) => cmd.name() // Just show the name, instead of short usage.
+  subcommandTerm: (cmd) => cmd.name(), // Just show the name, instead of short usage.
 });
 
-program.command('zebra <herd-size>', 'African equines with distinctive black-and-white striped coats');
-program.command('aardvark [colour]', 'medium-sized, burrowing, nocturnal mammal');
+program.command(
+  'zebra <herd-size>',
+  'African equines with distinctive black-and-white striped coats',
+);
+program.command(
+  'aardvark [colour]',
+  'medium-sized, burrowing, nocturnal mammal',
+);
 program
   .command('beaver', 'large, semiaquatic rodent')
   .option('--pond')
