@@ -1,7 +1,5 @@
 #!/usr/bin/env node
-
-// const commander = require('commander'); // (normal include)
-const commander = require('../'); // include commander in git clone of commander repo
+const commander = require('commander');
 
 // Use a class override to customise the command and its subcommands.
 
@@ -12,33 +10,31 @@ class CommandWithTrace extends commander.Command {
     cmd.option('-t, --trace', 'display extra information when run command');
     return cmd;
   }
-};
+}
 
-function inpectCommand(command) {
+function inspectCommand(command) {
   // The option value is stored as property on command because we called .storeOptionsAsProperties()
   console.log(`Called '${command.name()}'`);
   console.log(`args: ${command.args}`);
   console.log('opts: %o', command.opts());
-};
+}
 
 const program = new CommandWithTrace('program')
   .option('-v, ---verbose')
   .action((options, command) => {
-    inpectCommand(command);
+    inspectCommand(command);
   });
 
 program
   .command('serve [params...]')
   .option('-p, --port <number>', 'port number')
   .action((params, options, command) => {
-    inpectCommand(command);
+    inspectCommand(command);
   });
 
-program
-  .command('build <target>')
-  .action((buildTarget, options, command) => {
-    inpectCommand(command);
-  });
+program.command('build <target>').action((buildTarget, options, command) => {
+  inspectCommand(command);
+});
 
 program.parse();
 
