@@ -6,14 +6,10 @@
 // (A different pattern for a "global" option is to add it to the subcommands, rather
 // than to the program. See global-options-added.js.)
 
-// const { Command } = require('commander'); // (normal include)
-const { Command } = require('../'); // include commander in git clone of commander repo
-
+const { Command } = require('commander');
 const program = new Command();
 
-program
-  .configureHelp({ showGlobalOptions: true })
-  .option('-g, --global');
+program.configureHelp({ showGlobalOptions: true }).option('-g, --global');
 
 program
   .command('sub')
@@ -21,7 +17,7 @@ program
   .action((options, cmd) => {
     console.log({
       opts: cmd.opts(),
-      optsWithGlobals: cmd.optsWithGlobals()
+      optsWithGlobals: cmd.optsWithGlobals(),
     });
   });
 
