@@ -4,18 +4,38 @@
 // See also options-env.js for more extensive env examples,
 // and options-conflicts.js for more details about .conflicts().
 
-// const { Command, Option } = require('commander'); // (normal include)
-const { Command, Option } = require('../'); // include commander in git clone of commander repo
+const { Command, Option } = require('commander');
 const program = new Command();
 
 program
   .addOption(new Option('-s, --secret').hideHelp())
-  .addOption(new Option('-t, --timeout <delay>', 'timeout in seconds').default(60, 'one minute'))
-  .addOption(new Option('-d, --drink <size>', 'drink cup size').choices(['small', 'medium', 'large']))
+  .addOption(
+    new Option('-t, --timeout <delay>', 'timeout in seconds').default(
+      60,
+      'one minute',
+    ),
+  )
+  .addOption(
+    new Option('-d, --drink <size>', 'drink cup size').choices([
+      'small',
+      'medium',
+      'large',
+    ]),
+  )
   .addOption(new Option('-p, --port <number>', 'port number').env('PORT'))
-  .addOption(new Option('--donate [amount]', 'optional donation in dollars').preset('20').argParser(parseFloat))
-  .addOption(new Option('--disable-server', 'disables the server').conflicts('port'))
-  .addOption(new Option('--free-drink', 'small drink included free ').implies({ drink: 'small' }));
+  .addOption(
+    new Option('--donate [amount]', 'optional donation in dollars')
+      .preset('20')
+      .argParser(parseFloat),
+  )
+  .addOption(
+    new Option('--disable-server', 'disables the server').conflicts('port'),
+  )
+  .addOption(
+    new Option('--free-drink', 'small drink included free ').implies({
+      drink: 'small',
+    }),
+  );
 
 program.parse();
 
