@@ -2,8 +2,7 @@
 
 // This is used as an example in the README for variadic options.
 
-// const commander = require('commander'); // (normal include)
-const commander = require('../'); // include commander in git clone of commander repo
+const commander = require('commander');
 const program = new commander.Command();
 
 program
