@@ -1,12 +1,9 @@
 #!/usr/bin/env node
 
-// const { Command } = require('commander'); // (normal include)
-const { Command } = require('../'); // include commander in git clone of commander repo
+const { Command } = require('commander');
 const program = new Command();
 
-program
-  .enablePositionalOptions()
-  .option('-p, --progress');
+program.enablePositionalOptions().option('-p, --progress');
 
 program
   .command('upload <file>')
