@@ -1,11 +1,8 @@
-// const { program } = require('commander'); // (normal include)
-const { program } = require('../'); // include commander in git clone of commander repo
+const { program } = require('commander');
 
 // This is used as an example in the README for the Quick Start.
 
-program
-  .option('--first')
-  .option('-s, --separator <char>');
+program.option('--first').option('-s, --separator <char>').argument('<string>');
 
 program.parse();
 
