@@ -2,8 +2,7 @@
 
 // This example is used as an example in the README for the action handler.
 
-// const { Command } = require('commander'); // (normal include)
-const { Command } = require('../'); // include commander in git clone of commander repo
+const { Command } = require('commander');
 const program = new Command();
 
 program
