@@ -5,28 +5,21 @@ const commander = require('../');
 
 test('when command has alias then appears in help', () => {
   const program = new commander.Command();
-  program
-    .command('info [thing]')
-    .alias('i');
+  program.command('info [thing]').alias('i');
   const helpInformation = program.helpInformation();
   expect(helpInformation).toMatch('info|i');
 });
 
 test('when command has aliases added separately then only first appears in help', () => {
   const program = new commander.Command();
-  program
-    .command('list [thing]')
-    .alias('ls')
-    .alias('dir');
+  program.command('list [thing]').alias('ls').alias('dir');
   const helpInformation = program.helpInformation();
   expect(helpInformation).toMatch('list|ls ');
 });
 
 test('when command has aliases then only first appears in help', () => {
   const program = new commander.Command();
-  program
-    .command('list [thing]')
-    .aliases(['ls', 'dir']);
+  program.command('list [thing]').aliases(['ls', 'dir']);
   const helpInformation = program.helpInformation();
   expect(helpInformation).toMatch('list|ls ');
 });
@@ -34,19 +27,14 @@ test('when command has aliases then only first appears in help', () => {
 test('when command name = alias then error', () => {
   const program = new commander.Command();
   expect(() => {
-    program
-      .command('fail')
-      .alias('fail');
+    program.command('fail').alias('fail');
   }).toThrow("Command alias can't be the same as its name");
 });
 
 test('when use alias then action handler called', () => {
   const program = new commander.Command();
   const actionMock = jest.fn();
-  program
-    .command('list')
-    .alias('ls')
-    .action(actionMock);
+  program.command('list').alias('ls').action(actionMock);
   program.parse(['ls'], { from: 'user' });
   expect(actionMock).toHaveBeenCalled();
 });
@@ -54,11 +42,7 @@ test('when use alias then action handler called', () => {
 test('when use second alias added separately then action handler called', () => {
   const program = new commander.Command();
   const actionMock = jest.fn();
-  program
-    .command('list')
-    .alias('ls')
-    .alias('dir')
-    .action(actionMock);
+  program.command('list').alias('ls').alias('dir').action(actionMock);
   program.parse(['dir'], { from: 'user' });
   expect(actionMock).toHaveBeenCalled();
 });
@@ -66,10 +50,7 @@ test('when use second alias added separately then action handler called', () =>
 test('when use second of aliases then action handler called', () => {
   const program = new commander.Command();
   const actionMock = jest.fn();
-  program
-    .command('list')
-    .aliases(['ls', 'dir'])
-    .action(actionMock);
+  program.command('list').aliases(['ls', 'dir']).action(actionMock);
   program.parse(['dir'], { from: 'user' });
   expect(actionMock).toHaveBeenCalled();
 });
@@ -91,9 +72,7 @@ test('when set aliases then can get aliases', () => {
 test('when set alias on executable then can get alias', () => {
   const program = new commander.Command();
   const alias = 'abcde';
-  program
-    .command('external', 'external command')
-    .alias(alias);
+  program.command('external', 'external command').alias(alias);
   expect(program.commands[0].alias()).toEqual(alias);
 });
 
