@@ -21,20 +21,20 @@ class MyCommand extends commander.Command {
 test('when override createArgument then used for argument()', () => {
   const program = new MyCommand();
   program.argument('<file>');
-  expect(program._args.length).toEqual(1);
-  expect(program._args[0].myProperty).toEqual('MyArgument');
+  expect(program.registeredArguments.length).toEqual(1);
+  expect(program.registeredArguments[0].myProperty).toEqual('MyArgument');
 });
 
 test('when override createArgument then used for arguments()', () => {
   const program = new MyCommand();
   program.arguments('<file>');
-  expect(program._args.length).toEqual(1);
-  expect(program._args[0].myProperty).toEqual('MyArgument');
+  expect(program.registeredArguments.length).toEqual(1);
+  expect(program.registeredArguments[0].myProperty).toEqual('MyArgument');
 });
 
 test('when override createArgument and createCommand then used for argument of command()', () => {
   const program = new MyCommand();
   const sub = program.command('sub <file>');
-  expect(sub._args.length).toEqual(1);
-  expect(sub._args[0].myProperty).toEqual('MyArgument');
+  expect(sub.registeredArguments.length).toEqual(1);
+  expect(sub.registeredArguments[0].myProperty).toEqual('MyArgument');
 });
