@@ -5,10 +5,14 @@ const commander = require('../');
 // This is the default behaviour when no default command and no action handlers
 test('when no command specified and executable then display help', () => {
   // Optional. Suppress normal output to keep test output clean.
-  const writeSpy = jest.spyOn(process.stderr, 'write').mockImplementation(() => { });
+  const writeSpy = jest
+    .spyOn(process.stderr, 'write')
+    .mockImplementation(() => {});
   const program = new commander.Command();
   program
-    .exitOverride((err) => { throw err; })
+    .exitOverride((err) => {
+      throw err;
+    })
     .command('install', 'install description');
   expect(() => {
     program.parse(['node', 'test']);
