@@ -7,9 +7,7 @@ describe(".command('*')", () => {
   test('when action handler for subcommand then emit command:subcommand', () => {
     const mockListener = jest.fn();
     const program = new commander.Command();
-    program
-      .command('sub')
-      .action(() => {});
+    program.command('sub').action(() => {});
     program.on('command:sub', mockListener);
     program.parse(['sub'], { from: 'user' });
     expect(mockListener).toHaveBeenCalled();
@@ -18,8 +16,7 @@ describe(".command('*')", () => {
   test('when no action handler for subcommand then still emit command:subcommand', () => {
     const mockListener = jest.fn();
     const program = new commander.Command();
-    program
-      .command('sub');
+    program.command('sub');
     program.on('command:sub', mockListener);
     program.parse(['sub'], { from: 'user' });
     expect(mockListener).toHaveBeenCalled();
@@ -28,9 +25,7 @@ describe(".command('*')", () => {
   test('when subcommand has argument then emit command:subcommand with argument', () => {
     const mockListener = jest.fn();
     const program = new commander.Command();
-    program
-      .command('sub <file>')
-      .action(() => {});
+    program.command('sub <file>').action(() => {});
     program.on('command:sub', mockListener);
     program.parse(['sub', 'file'], { from: 'user' });
     expect(mockListener).toHaveBeenCalledWith(['file'], []);
