@@ -1,9 +1,7 @@
 #!/usr/bin/env node
 
-const program = require('../../');
+const { program } = require('../../');
 
 process.env.FORCE_COLOR = 0; // work-around bug in Jest: https://github.com/jestjs/jest/issues/14391
 
-program
-  .command('sub', 'install one or more packages')
-  .parse(process.argv);
+program.command('sub', 'install one or more packages').parse(process.argv);
