@@ -14,7 +14,9 @@ describe('longestArgumentTermLength', () => {
     const program = new commander.Command();
     program.argument('<wonder>', 'wonder description');
     const helper = new commander.Help();
-    expect(helper.longestArgumentTermLength(program, helper)).toEqual('wonder'.length);
+    expect(helper.longestArgumentTermLength(program, helper)).toEqual(
+      'wonder'.length,
+    );
   });
 
   test('when has multiple argument descriptions then returns longest', () => {
@@ -23,6 +25,8 @@ describe('longestArgumentTermLength', () => {
     program.argument('<longest>', 'x');
     program.argument('<beta>', 'x');
     const helper = new commander.Help();
-    expect(helper.longestArgumentTermLength(program, helper)).toEqual('longest'.length);
+    expect(helper.longestArgumentTermLength(program, helper)).toEqual(
+      'longest'.length,
+    );
   });
 });
