@@ -9,7 +9,7 @@ describe('Option methods that should return this for chaining', () => {
 
   test('when call .argParser() then returns this', () => {
     const option = new Option('-e,--example <value>');
-    const result = option.argParser(() => { });
+    const result = option.argParser(() => {});
     expect(result).toBe(option);
   });
 
@@ -42,4 +42,10 @@ describe('Option methods that should return this for chaining', () => {
     const result = option.conflicts(['a']);
     expect(result).toBe(option);
   });
+
+  test('when call .helpGroup(heading) then returns this', () => {
+    const option = new Option('-e,--example <value>');
+    const result = option.helpGroup('Options:');
+    expect(result).toBe(option);
+  });
 });
