@@ -4,16 +4,14 @@ const commander = require('../');
 describe('option with optional value, no default', () => {
   test('when option not specified then value is undefined', () => {
     const program = new commander.Command();
-    program
-      .option('--cheese [type]', 'cheese type');
+    program.option('--cheese [type]', 'cheese type');
     program.parse(['node', 'test']);
     expect(program.opts().cheese).toBeUndefined();
   });
 
   test('when option specified then value is as specified', () => {
     const program = new commander.Command();
-    program
-      .option('--cheese [type]', 'cheese type');
+    program.option('--cheese [type]', 'cheese type');
     const cheeseType = 'blue';
     program.parse(['node', 'test', '--cheese', cheeseType]);
     expect(program.opts().cheese).toBe(cheeseType);
@@ -21,8 +19,7 @@ describe('option with optional value, no default', () => {
 
   test('when option specified without value then value is true', () => {
     const program = new commander.Command();
-    program
-      .option('--cheese [type]', 'cheese type');
+    program.option('--cheese [type]', 'cheese type');
     program.parse(['node', 'test', '--cheese']);
     expect(program.opts().cheese).toBe(true);
   });
@@ -30,9 +27,7 @@ describe('option with optional value, no default', () => {
   test('when option specified without value and following option then value is true', () => {
     // optional options do not eat values with dashes
     const program = new commander.Command();
-    program
-      .option('--cheese [type]', 'cheese type')
-      .option('--some-option');
+    program.option('--cheese [type]', 'cheese type').option('--some-option');
     program.parse(['node', 'test', '--cheese', '--some-option']);
     expect(program.opts().cheese).toBe(true);
   });
@@ -43,8 +38,7 @@ describe('option with optional value, with default', () => {
   test('when option not specified then value is default', () => {
     const defaultValue = 'default';
     const program = new commander.Command();
-    program
-      .option('--cheese [type]', 'cheese type', defaultValue);
+    program.option('--cheese [type]', 'cheese type', defaultValue);
     program.parse(['node', 'test']);
     expect(program.opts().cheese).toBe(defaultValue);
   });
@@ -52,8 +46,7 @@ describe('option with optional value, with default', () => {
   test('when option specified then value is as specified', () => {
     const defaultValue = 'default';
     const program = new commander.Command();
-    program
-      .option('--cheese [type]', 'cheese type', defaultValue);
+    program.option('--cheese [type]', 'cheese type', defaultValue);
     const cheeseType = 'blue';
     program.parse(['node', 'test', '--cheese', cheeseType]);
     expect(program.opts().cheese).toBe(cheeseType);
@@ -62,16 +55,14 @@ describe('option with optional value, with default', () => {
   test('when option specified without value then value is true', () => {
     const defaultValue = 'default';
     const program = new commander.Command();
-    program
-      .option('--cheese [type]', 'cheese type', defaultValue);
+    program.option('--cheese [type]', 'cheese type', defaultValue);
     program.parse(['node', 'test', '--cheese']);
     expect(program.opts().cheese).toBe(true);
   });
 
   test('when option specified without value and preset then value is preset', () => {
     const program = new commander.Command();
-    program
-      .addOption(new commander.Option('--cheese [type]').preset('preset'));
+    program.addOption(new commander.Option('--cheese [type]').preset('preset'));
     program.parse(['node', 'test', '--cheese']);
     expect(program.opts().cheese).toBe('preset');
   });
