@@ -4,16 +4,14 @@ const commander = require('../');
 describe('option with required value, no default', () => {
   test('when option not specified then value is undefined', () => {
     const program = new commander.Command();
-    program
-      .option('--cheese <type>', 'cheese type');
+    program.option('--cheese <type>', 'cheese type');
     program.parse(['node', 'test']);
     expect(program.opts().cheese).toBeUndefined();
   });
 
   test('when option specified then value is as specified', () => {
     const program = new commander.Command();
-    program
-      .option('--cheese <type>', 'cheese type');
+    program.option('--cheese <type>', 'cheese type');
     const cheeseType = 'blue';
     program.parse(['node', 'test', '--cheese', cheeseType]);
     expect(program.opts().cheese).toBe(cheeseType);
@@ -26,8 +24,7 @@ describe('option with required value, no default', () => {
     });
     const program = new commander.Command();
     program.optionMissingArgument = mockOptionMissingArgument;
-    program
-      .option('--cheese <type>', 'cheese type');
+    program.option('--cheese <type>', 'cheese type');
 
     // Act. The throw is due to the above mock, and not default behaviour.
     expect(() => {
@@ -44,8 +41,7 @@ describe('option with required value, with default', () => {
   test('when option not specified then value is default', () => {
     const defaultValue = 'default';
     const program = new commander.Command();
-    program
-      .option('--cheese <type>', 'cheese type', defaultValue);
+    program.option('--cheese <type>', 'cheese type', defaultValue);
     program.parse(['node', 'test']);
     expect(program.opts().cheese).toBe(defaultValue);
   });
@@ -53,8 +49,7 @@ describe('option with required value, with default', () => {
   test('when option specified then value is as specified', () => {
     const defaultValue = 'default';
     const program = new commander.Command();
-    program
-      .option('--cheese <type>', 'cheese type', defaultValue);
+    program.option('--cheese <type>', 'cheese type', defaultValue);
     const cheeseType = 'blue';
     program.parse(['node', 'test', '--cheese', cheeseType]);
     expect(program.opts().cheese).toBe(cheeseType);
@@ -68,8 +63,7 @@ describe('option with required value, with default', () => {
     const defaultValue = 'default';
     const program = new commander.Command();
     program.optionMissingArgument = mockOptionMissingArgument;
-    program
-      .option('--cheese <type>', 'cheese type', defaultValue);
+    program.option('--cheese <type>', 'cheese type', defaultValue);
 
     // Act. The throw is due to the above mock, and not default behaviour.
     expect(() => {
